@@ -249,7 +249,8 @@ def starstab(date):
 
     # returns 3 tables with SHA & Mer.pass for Venus, Mars, Jupiter and Saturn
     for i in range(3):
-        datestr = r'''{} {} {}'''.format(ephem.date(date+i).datetime().strftime("%b"), ephem.date(date+i).datetime().strftime("%d"), ephem.date(date+i).datetime().strftime("%a"))
+        dt = ephem.date(date+i).datetime()
+        datestr = r'''{} {} {}'''.format(dt.strftime("%b"), dt.strftime("%d"), dt.strftime("%a"))
         m = m + '''\hline
 '''
         if config.tbls == "m":
@@ -845,8 +846,8 @@ def almanac(first_day, pagenum, dfA4):
         rm1 = "10mm"
         tm = "21mm"     # data pages...
         bm = "18mm"
-        lm = "12mm"
-        rm = "8mm"
+        lm = "10mm"
+        rm = "9mm"
         if config.tbls == "m":
             tm = "10mm"
             bm = "15mm"
